==> pyclustering-0.8.0.tar.gz: pyclustering-0.8.0/ccore/src/parallel/thread_executor.hpp <==
/**
*
* Copyright (C) 2014-2018    Andrei Novikov (pyclustering@yandex.ru)
*
* GNU_PUBLIC_LICENSE
*   pyclustering is free software: you can redistribute it and/or modify
*   it under the terms of the GNU General Public License as published by
*   the Free Software Foundation, either version 3 of the License, or
*   (at your option) any later version.
*
*   pyclustering is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty of
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*   GNU General Public License for more details.
*
*   You should have received a copy of the GNU General Public License
*   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*
*/


#pragma once


#include <atomic>
#include <condition_variable>
#include <thread>

#include "task.hpp"


namespace ccore {

namespace parallel {


class thread_executor {
public:
    using task_getter   = std::function<void(task::ptr &)>;
    using task_notifier = std::function<void(const task::ptr &)>;

    using ptr           = std::shared_ptr<thread_executor>;

private:
    bool                    m_stop            = true;

    task_getter             m_getter          = nullptr;
    task_notifier           m_notifier        = nullptr;

    std::thread             m_executor;

public:
    thread_executor(void) = default;

    explicit thread_executor(const task_getter & p_getter, const task_notifier & p_reporter);

    thread_executor(const thread_executor & p_other) = delete;

    thread_executor(thread_executor && p_other) = delete;

    ~thread_executor(void) = default;

public:
    void stop(void);

private:
    void run(void);
};


}

}

==> pyclustering-0.8.1.tar.gz: pyclustering-0.8.1/ccore/src/parallel/thread_executor.hpp <==
/**
*
* Copyright (C) 2014-2018    Andrei Novikov (pyclustering@yandex.ru)
*
* GNU_PUBLIC_LICENSE
*   pyclustering is free software: you can redistribute it and/or modify
*   it under the terms of the GNU General Public License as published by
*   the Free Software Foundation, either version 3 of the License, or
*   (at your option) any later version.
*
*   pyclustering is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty of
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*   GNU General Public License for more details.
*
*   You should have received a copy of the GNU General Public License
*   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*
*/


#pragma once


#include <atomic>
#include <condition_variable>
#include <thread>

#include "task.hpp"


namespace ccore {

namespace parallel {


class thread_executor {
public:
    using task_getter   = std::function<void(task::ptr &)>;
    using task_notifier = std::function<void(const task::ptr &)>;

    using ptr           = std::shared_ptr<thread_executor>;

private:
    bool                    m_stop            = true;

    task_getter             m_getter          = nullptr;
    task_notifier           m_notifier        = nullptr;

    std::thread             m_executor;

public:
    thread_executor(void) = default;

    explicit thread_executor(const task_getter & p_getter, const task_notifier & p_notifier);

    thread_executor(const thread_executor & p_other) = delete;

    thread_executor(thread_executor && p_other) = delete;

    ~thread_executor(void) = default;

public:
    void stop(void);

private:
    void run(void);
};


}

}
